@@ -78,7 +78,7 @@ class SendingMixin:
     async def send(
         self: ResultSendProtocol, message: SendingMessage, *, update: bool = False,
     ) -> UUID:
-        """Send message as answer to command or notification to chat and get it id.
+        """Send message as direct notification to chat and get it id.
 
         Arguments:
             message: message that should be sent to chat.
@@ -97,9 +97,6 @@ class SendingMixin:
             )
             return message.credentials.message_id
 
-        if message.sync_id:
-            return await self.send_command_result(message.credentials, message.payload)
-
         return await self.send_direct_notification(message.credentials, message.payload)
 
     async def answer_message(  # noqa: WPS211
@@ -135,7 +132,7 @@ class SendingMixin:
 
         return await self.send(sending_message)
 
-    async def send_file(  # noqa: WPS211
+    async def send_file(
         self: MessageSendProtocol,
         file: Union[TextIO, BinaryIO, File],
         credentials: SendingCredentials,
