@@ -2,10 +2,12 @@
 
 from typing import Optional
 
-from pydantic import BaseModel, validator
+from pydantic import validator
+
+from botx.models.base import BotXBaseModel
 
 
-class ButtonOptions(BaseModel):
+class ButtonOptions(BotXBaseModel):
     """Extra options for buttons, like disabling output by tap."""
 
     #: if True then text won't shown for user in messenger.
@@ -25,7 +27,6 @@ class ButtonOptions(BaseModel):
         """Validate that `h_size` is positive integer.
 
         Arguments:
-            cls: this class.
             h_size: width weight for validation.
 
         Returns:
@@ -40,7 +41,7 @@ class ButtonOptions(BaseModel):
         return h_size
 
 
-class Button(BaseModel):
+class Button(BotXBaseModel):
     """Base class for ui element like bubble or keyboard button."""
 
     #: command that will be triggered by click on the element.
@@ -62,7 +63,6 @@ class Button(BaseModel):
         """Return command as label if it is `None`.
 
         Arguments:
-            cls: passed button class.
             label: value that should be checked.
             values: all other validated_values checked before.
 
@@ -76,7 +76,6 @@ class Button(BaseModel):
         """Return command data with set UI flag.
 
         Arguments:
-            cls: passed button class.
             button_data: data passed to bot.
 
         Returns:
